@@ -2,7 +2,6 @@ import os.path
 
 from . import callback
 from . import evaluation
-from . import io
 from . import layer
 from . import module
 from . import notebook
@@ -13,6 +12,7 @@ from . import visualization
 from .neko_module import NekoModule
 from .neko_model import NekoModel
 from .neko_trainer import NekoTrainer
+from tensorneko_util import io
 
 __all__ = [
     "callback",
@@ -30,4 +30,4 @@ __all__ = [
     "NekoModule"
 ]
 
-__version__ = io.read.text.of(os.path.join(util.get_tensorneko_path(), "version.txt"))
+__version__ = io.read.text(os.path.join(util.get_tensorneko_path(), "version.txt"))
